# Author by songht.CMB.bnu 
# Date: 2017-12-01
#!/bin/sh
export perl="/userset/perl"


#############################################################################################
# Step1 dataset_preparation        										                       
# Usage: Filtered the scaffolds whose length are less than length_cutoff                    
#      Depedency_tools: scaffold_filter.pl, remove_nobase.pl 	                            
#      Input: scaffold or chromosome fasta files in each species                            
#      Output: species_scaffold_good.fa 							                        
#############################################################################################

echo 'Step1 start at'
date
export genome_fasta="/Userset/genome_fasta"
export good_fasta="/Userset/good_fasta"
export pl_scripts="/Userset/scripts"
export length_cutoff=2000
for spec in Cucumber Cucu-me Water-melo Malus-dome Glyc-max Popu-tr Citrus Brass-ra Arab-ly Arab-th Viti-vi Sola-tu Seta-ti Oryza-brach Brach
	do
		echo "#### Step1.1 filtered the scaffolds whose length were less than $length_cutoff ####"
		perl $pl_scripts/scaffold_filter.pl $genome_fasta/$spec.fasta $length_cutoff > $good_fasta/$spec\_scaffold_filtered.fa
		echo "#### Step1.2 remove the nobases in the scaffold sequences  ####"
		perl $pl_scripts/remove_nobase.pl $good_fasta/$spec\_scaffold_filtered.fa > $good_fasta/$spec.fa
	done

echo 'Step1 Finished at'
date


##############################################################################################
# Step2 Pair-wise alignment using LASTZ tool with cucumber genome as reference     			 
#       This script was a reference to online resource										 
#       From 2.1 to 2.8 step by step														 
# Usage:Aligning each of other 14 species genome to reference genome                         
#      Dependency_tools:lastz-1.02.00,ucsc_tool,pslSplitOnTarget_myself.pl,GAP_matrix_plant  																		
#      Input: target_genome:Cucumber_scaffold_good.fa quary_genome:each of other 14 genomes  
#      Output: maf_files [Multiple Alignment Format]										
##############################################################################################


echo 'Step2 Start at'
date
export Lastz="/Userset/lastz-distrib-1.02.00/bin"
export ucsc="/Userset/ucsc_src"
export scaffold_dir="/Userset/scaffold_data"
export WRKDIR="/Userset/species_vs_Cucumber" 

echo "####From Target.fa Query.fa To Lastz and chainning into Maf#####"
echo "#####Step2.1 split fa file into smaller ones by name####"
cd ${WRKDIR}
export TNAME="target_species"
export QNAME=Cucumber
export TARGET=${scaffold}/${TNAME}.fa
export QUERY=${scaffold}/${QNAME}.fa
export MATRIX="./GAP_matrix_plant"
mkdir ${TNAME}  ${QNAME}
${ucsc}/faSplit byname ${TARGET} ${TNAME}/
${ucsc}/faSplit byname ${QUERY} ${QNAME}/

echo "#####Step2.1 run lastz for every one of Q with T out=lav####"
mkdir lav_results
cd ${WRKDIR}
export T_num=$(ls ${TNAME}/| grep "fa"| wc -l)
export Q_num=$(ls ${QNAME}/| grep "fa"| wc -l)
echo ${T_num} "in Target" ${Q_num} "in QUERY"
for i in ./${TNAME}/*.fa
	{
		for j in ./${QNAME}/*.fa
			{
				echo $i $j
				# running parameters from MBE paper with PubmedID:23640124 
				$lastz  $i $j --inner=2000 --xdrop=9400 --gappedthresh=3000 --hspthresh=2200 --format=lav  > lav_results/`basename $i`-`basename $j`.lav
			}
	}

echo "####Step2.2 Convert the lav files into psl format####"
mkdir psl_results
for i in lav_results/*.lav; do echo $i; ${ucsc}/lavToPsl $i psl_results/`basename $i .lav`.psl; done;
cat psl_results/*.psl > all.psl
${ucsc}/pslSwap all.psl all-swap.psl

echo "####Step2.3 perl myself pslSplitOnTarget.pl####"
mkdir psl_fine
perl $pl_scripts/pslSplitOnTarget_myself.pl all-swap.psl psl_fine/

echo "####Step2.4 Chainning####"
###creat the nib files for t and q###
for i in ./${TNAME}/*.fa; do echo $i; ${ucsc}/faToNib $i ./${TNAME}/`basename $i .fa`.nib; done
for i in ./${QNAME}/*.fa; do echo $i; ${ucsc}/faToNib $i ./${QNAME}/`basename $i .fa`.nib; done
mkdir chain
for i in psl_fine/*.psl; do echo $i; ${ucsc}/axtChain $i ${QNAME} ${TNAME} chain/`basename $i .psl`.chain -linearGap=${MATRIX} -psl; done


echo "####Step2.5 creat the size of chromosome####"
${ucsc}/faSize ${TARGET} -detailed > ${TNAME}.sizes
${ucsc}/faSize ${QUERY} -detailed > ${QNAME}.sizes

echo "####Step2.6 Sort and filter the chains####"
${ucsc}/chainMergeSort chain/*.chain > all.chain
${ucsc}/chainPreNet all.chain ${QNAME}.sizes ${TNAME}.sizes all.pre.chain

echo "####Step2.7 Netting####"
${ucsc}/chainNet all.pre.chain -minSpace=1 ${QNAME}.sizes ${TNAME}.sizes stdout /dev/null | ${ucsc}/netSyntenic stdin noClass.net

echo "####Step2.8 Maffing####"
${ucsc}/netToAxt noClass.net all.pre.chain ${QNAME}/ ${TNAME}/ stdout | ${ucsc}/axtSort stdin ${TNAME}_${QNAME}.axt
${ucsc}/axtToMaf ${TNAME}_${QNAME}.axt ${QNAME}.sizes ${TNAME}.sizes ${TNAME}_${QNAME}.maf -qPrefix=${TNAME}. -tPrefix=${QNAME}.
${ucsc}/mafSplit -byTarget dummy.bed maf/ ${TNAME}_${QNAME}.maf

echo "####Congratulation! All steps have been finished!#####"

echo -ne 'End at '
date



##############################################################################################
# Step3 Multiple alignment using MULTIZ tool to merge the 14 pair-wise alignments above      # 
#       From 3.1 to 3.14 step by step														 #
# Usage:Species indexed by d, where d is gradually increased with the divergence from        #
#       cucumber according to the phylogenetic tree in Figure 1                              #
#      Dependency_tools:multiz-tba.012109										             #																						 #
#      Input: Other 14 pair-wised maf files [named by species_Cucumber.maf]				     # 
#      Output: n-way maf_files [n=3~15]							             				 #
##############################################################################################

echo 'Step3 Start at'
date

export multiz='/Userset/multiz-tba.012109'
export maf_files="Userset/maf_files"
export multiz_files="Userset/multiz_files"
export ref_spec='Cucumber'
export spec_2='Cucu-me'
export spec_3='Water-melo'
export spec_4='Malus-dome'
export spec_5='Glyc-max'
export spec_6='Popu-tr'
export spec_7='Citrus'
export spec_8='Brass-ra'
export spec_9='Arab-th'
export spec_10='Arab-ly'
export spec_11='Viti-vi'
export spec_12='Sola-tu'
export spec_13='Seta-ti'
export spec_14='Brach'
export spec_15='Oryza-brach'

echo 'Step 3.1 Using MULTIZ to produce 3-way alignment maf file'
$multiz/multiz ${maf_files}/$spec_2\_Cucumber.maf ${maf_files}/$spec_3\_Cucumber.maf 1 > ${multiz_files}/3way.multiz

echo 'Step 3.2 Using MULTIZ to produce 4-way alignment maf file'
$multiz/multiz ${multiz_files}/3way.multiz ${maf_files}/$spec_4\_Cucumber.maf 1 > ${multiz_files}/4way.multiz

echo 'Step 3.3 Using MULTIZ to produce 5-way alignment maf file'
$multiz/multiz ${multiz_files}/4way.multiz ${maf_files}/$spec_5\_Cucumber.maf 1 > ${multiz_files}/5way.multiz

echo 'Step 3.4 Using MULTIZ to produce 6-way alignment maf file'
$multiz/multiz ${multiz_files}/5way.multiz ${maf_files}/$spec_6\_Cucumber.maf 1 > ${multiz_files}/6way.multiz

echo 'Step 3.5 Using MULTIZ to produce 7-way alignment maf file'
$multiz/multiz ${multiz_files}/6way.multiz ${maf_files}/$spec_7\_Cucumber.maf 1 > ${multiz_files}/7way.multiz

echo 'Step 3.6 Using MULTIZ to produce 8-way alignment maf file'
$multiz/multiz ${multiz_files}/7way.multiz ${maf_files}/$spec_8\_Cucumber.maf 1 > ${multiz_files}/8way.multiz

echo 'Step 3.7 Using MULTIZ to produce 9-way alignment maf file'
$multiz/multiz ${multiz_files}/8way.multiz ${maf_files}/$spec_9\_Cucumber.maf 1 > ${multiz_files}/9way.multiz

echo 'Step 3.8 Using MULTIZ to produce 10-way alignment maf file'
$multiz/multiz ${multiz_files}/9way.multiz ${maf_files}/$spec_10\_Cucumber.maf 1 > ${multiz_files}/10way.multiz

echo 'Step 3.9 Using MULTIZ to produce 11-way alignment maf file'
$multiz/multiz ${multiz_files}/10way.multiz ${maf_files}/$spec_11\_Cucumber.maf 1 > ${multiz_files}/11way.multiz

echo 'Step 3.10 Using MULTIZ to produce 12-way alignment maf file'
$multiz/multiz ${multiz_files}/11way.multiz ${maf_files}/$spec_12\_Cucumber.maf 1 > ${multiz_files}/12way.multiz

echo 'Step 3.11 Using MULTIZ to produce 13-way alignment maf file'
$multiz/multiz ${multiz_files}/12way.multiz ${maf_files}/$spec_13\_Cucumber.maf 1 > ${multiz_files}/13way.multiz

echo 'Step 3.12 Using MULTIZ to produce 14-way alignment maf file'
$multiz/multiz ${multiz_files}/13way.multiz ${maf_files}/$spec_14\_Cucumber.maf 1 > ${multiz_files}/14way.multiz

echo 'Step 3.13 Using MULTIZ to produce 15-way alignment maf file'
$multiz/multiz ${multiz_files}/14way.multiz ${maf_files}/$spec_15\_Cucumber.maf 1 > ${multiz_files}/15way.multiz

echo 'MULTIZ finished at'
date

